gh

package
v1.7.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 30, 2026 License: MIT Imports: 15 Imported by: 0

Documentation

Overview

package gh contains github related actions

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ActionAgents added in v1.6.5

func ActionAgents() carapace.Action

ActionAgents completes known agents

github-copilot
crush

func ActionAuthScopes

func ActionAuthScopes() carapace.Action

ActionAuthScopes completes authentication scopes

admin:gpg_key (Fully manage GPG keys)
admin:org (Fully manage the organization and its teams, projects, and memberships)

func ActionAutolinkFields added in v1.3.0

func ActionAutolinkFields() carapace.Action

ActionAutolinkFields completes autolink fields

id
isAlphanumeric
func ActionAutolinks(opts RepoOpts) carapace.Action

ActionAutolinks completes autolinks

1111111 (TICKET-)
2222222 (STORY-)

func ActionCacheFields

func ActionCacheFields() carapace.Action

ActionCacheFields completes label fields

id
key

func ActionCacheRefs added in v1.0.1

func ActionCacheRefs(opts RepoOpts) carapace.Action

ActionCacheRefs completes cache refs

refs/pull/1718/merge
refs/heads/master

func ActionCaches

func ActionCaches(opts RepoOpts) carapace.Action

ActionCaches completes caches

41 (refs/pull/1718/merge)
42 (refs/heads/master)

func ActionCodespaceViewFields

func ActionCodespaceViewFields() carapace.Action

ActionCodespaceViewFields completes codespace fields for view

displayName
repository

func ActionCommitFields

func ActionCommitFields() carapace.Action

ActionCommitFields completes commit fields

author
commit

func ActionConfigHosts

func ActionConfigHosts() carapace.Action

ActionConfigHosts completes configured hosts

github.com
another.com

func ActionConfigUsers

func ActionConfigUsers(host string) carapace.Action

ActionConfigUsers completes configured users

userA
userB

func ActionContents

func ActionContents(opts ContentOpts) carapace.Action

ActionContents completes contents

/README.md
/.github/workflows/go.yml

func ActionCurrentAuthScopes

func ActionCurrentAuthScopes(hostname string) carapace.Action

ActionCurrentAuthScopes completes current authentication scopes for given hostname

admin:gpg_key (Fully manage GPG keys)
admin:org (Fully manage the organization and its teams, projects, and memberships)

func ActionDateFields

func ActionDateFields() carapace.Action

ActionDateFields completes date fields

<=2023-01-01
2022-01-01...2023-01-01

func ActionDeployKeyFields

func ActionDeployKeyFields() carapace.Action

ActionDeployKeyFields completes deploy key fields

id
key

func ActionDiscussionCategories added in v1.7.2

func ActionDiscussionCategories(opts RepoOpts) carapace.Action

ActionDiscussionCategories completes discussion categories

Announcements (General announcements)
Ideas (Ideas and suggestions)

func ActionDiscussionListFields added in v1.7.2

func ActionDiscussionListFields() carapace.Action

ActionDiscussionListFields completes discussion list fields

answerChosenAt
answerChosenBy

func ActionDiscussionViewFields added in v1.7.2

func ActionDiscussionViewFields() carapace.Action

ActionDiscussionViewFields completes discussion view fields

answerChosenAt
answerChosenBy

func ActionDiscussions added in v1.7.2

func ActionDiscussions(opts RepoOpts) carapace.Action

ActionDiscussions completes discussions

11 (discussion title)
12 (discussion title)

func ActionEmojis

func ActionEmojis() carapace.Action

ActionEmojis completes emoji names

100 (💯 hundred points)
1234 (🔢 input numbers)

func ActionEnvironmentVariables

func ActionEnvironmentVariables(opts EnvironmentOpts) carapace.Action

ActionEnvironmentVariables completes environment variables

first (value1)
second (value2)

func ActionGpgKeys

func ActionGpgKeys(opts HostOpts) carapace.Action

ActionGpgKeys completes gpg keys

AABBCCDDEEFF112 (example)
AABBCCDDEEFF113 (another)

func ActionHostOwnerRepositories added in v1.0.1

func ActionHostOwnerRepositories() carapace.Action

ActionHostOwnerRepositories completes [host/]owner/repository

carapace-sh/carapace
github.com/carapace-sh/carapace

func ActionIssueTemplates

func ActionIssueTemplates(opts RepoOpts) carapace.Action

ActionIssueTemplates completes issue templates

⭐ Submit a request (Surface a feature or problem that you think should be solved)
🐛 Bug report (Report a bug or unexpected behavior while using GitHub CLI)

func ActionIssueTypes added in v1.7.2

func ActionIssueTypes(opts RepoOpts) carapace.Action

ActionIssueTypes completes issue types

Bug (Something that doesn't work)
Feature (A new feature)

func ActionLabelFields

func ActionLabelFields() carapace.Action

ActionLabelFields completes label fields

color
createdAt

func ActionLabels

func ActionLabels(opts RepoOpts) carapace.Action

ActionLabels completes labels

enhancement (New feature or request)
good first issue (Good for newcomers)

func ActionLanguages added in v1.0.1

func ActionLanguages() carapace.Action

ActionLanguages completes repository languages

Go (programming)
Go Checksums (data)

func ActionLicenses

func ActionLicenses(opts HostOpts) carapace.Action

ActionLicenses completes licenses

apache-2.0 (Apache License 2.0)
bsd-2-clause (BSD 2-Clause "Simplified" License)

func ActionOrganisationVariables

func ActionOrganisationVariables(opts OwnerOpts) carapace.Action

ActionOrganisationVariables completes organisation variables

first (value1)
second (value2)

func ActionOrganizationEmails added in v1.0.7

func ActionOrganizationEmails(opts OwnerOpts) carapace.Action

ActionOrganizationEmails completes email for given organization

team@example.com
dev@example.com

func ActionOrganizations

func ActionOrganizations(opts HostOpts) carapace.Action

ActionOrganizations completes organizations

org (organization name)
another (another name)

func ActionOwnerRepositories

func ActionOwnerRepositories(opts HostOpts) carapace.Action

ActionOwnerRepositories completes owner/repository

carapace-sh/carapace
spf13/cobra

func ActionOwners

func ActionOwners(opts HostOpts) carapace.Action

ActionOwners completes users and organizations

user (user name)
org (organization name)

func ActionPinnedIssues

func ActionPinnedIssues(opts RepoOpts) carapace.Action

ActionPinnedIssues completes pinned issues

11 (issue description)
12 (issue description)

func ActionProjectItems

func ActionProjectItems(opts ProjectItemOpts) carapace.Action

ActionProjectItems completes project items

PVTI_lADOA48Fh84ABd_DzgBCG7c (Issue commands do not work with non-classic Projects)
PVTI_lADOA48Fh84ABd_DzgBCHAo (Checkout branch for issue)

func ActionProjects

func ActionProjects(opts ProjectOpts) carapace.Action

ActionProjects completes projects

1 (first project)
2 (second project)

func ActionPullRequestTemplates

func ActionPullRequestTemplates(opts RepoOpts) carapace.Action

ActionPullRequestTemplates completes pull request templates

PULL_REQUEST_TEMPLATE.md (content)

func ActionPullRequests added in v1.6.4

func ActionPullRequests(opts PullRequestOpts) carapace.Action

ActionPullRequests completes pull requests

1 (Fix login bug)
2 (Add feature)

TODO quickly moved over from gh_completer - needs polishing (and removal of the old one)

func ActionReadDirFields added in v1.7.2

func ActionReadDirFields() carapace.Action

ActionReadDirFields completes repo read-dir fields

gitSHA
gitType

func ActionReadFileFields added in v1.7.2

func ActionReadFileFields() carapace.Action

ActionReadFileFields completes repo read-file fields

content
downloadUrl

func ActionReleaseFields

func ActionReleaseFields() carapace.Action

ActionReleaseFields completes release fields

name
tagName

func ActionRepositories

func ActionRepositories(opts OwnerOpts) carapace.Action

ActionRepositories completes repositories

carapace (command argument completion generator for spf13/cobra)
carapace-bin (multi-shell multi-command argument completer)

func ActionRepositoryVariables

func ActionRepositoryVariables(opts RepoOpts) carapace.Action

ActionRepositoryVariables completes repository variables

first (value1)
second (value2)

func ActionRulesets

func ActionRulesets(opts RepoOpts) carapace.Action

ActionRulesets completes rulesets

1 (Rules)
2 (Another)

func ActionSecretFields

func ActionSecretFields() carapace.Action

ActionSecretFields completes secret fields

name
visibility

func ActionSessionFields added in v1.6.4

func ActionSessionFields() carapace.Action

ActionSessionFields completes session fields

id
name

func ActionSkillListFields added in v1.7.2

func ActionSkillListFields() carapace.Action

ActionSkillListFields completes skill list fields

agentHosts
path

func ActionSkills added in v1.6.5

func ActionSkills(opts RepoOpts) carapace.Action

ActionSkills completes skills

re-codebase-knowledge
add-educational-comments

func ActionSshKeys

func ActionSshKeys(opts HostOpts) carapace.Action

ActionSshKeys completes ssh keys

12345678 (title)
23456789 (another)

func ActionTeams added in v1.0.1

func ActionTeams(opts OwnerOpts) carapace.Action

ActionTeams completes teams

first-team (description of first team)
second-team (description of second team)

func ActionUserEmails added in v1.0.7

func ActionUserEmails(opts OwnerOpts) carapace.Action

ActionUserEmails completes email for given user

user@example.com (primary)
other@example.com

func ActionUsers

func ActionUsers(opts HostOpts) carapace.Action

ActionUsers completes users

user (user name)
another (another name)

func ActionVariableFields

func ActionVariableFields() carapace.Action

ActionVariableFields completes variable fields

name
value

func ActionWorkflowEvents

func ActionWorkflowEvents() carapace.Action

ActionWorkflowEvents completes events triggering a workflow

create
delete

func ActionWorkflowFields

func ActionWorkflowFields() carapace.Action

ActionWorkflowFields completes workflow fields.

name
state

Types

type ContentOpts

type ContentOpts struct {
	Host   string
	Owner  string
	Name   string
	Branch string
	Path   string // TODO should be handled using `Context.Value`
}

type EnvironmentOpts

type EnvironmentOpts struct {
	Host        string
	Owner       string
	Name        string
	Environment string
}

type HostOpts

type HostOpts struct {
	Host string
}

type OwnerOpts

type OwnerOpts struct {
	Host  string
	Owner string
}

type ProjectItemOpts

type ProjectItemOpts struct {
	Host     string
	Owner    string
	Project  int
	Archived bool
}

type ProjectOpts

type ProjectOpts struct {
	Host   string
	Owner  string
	Open   bool
	Closed bool
}

func (ProjectOpts) Default

func (o ProjectOpts) Default() ProjectOpts

type PullRequestOpts added in v1.6.4

type PullRequestOpts struct {
	Host  string
	Owner string
	Name  string

	Closed    bool
	Merged    bool
	Open      bool
	DraftOnly bool
}

func (PullRequestOpts) Default added in v1.6.4

func (o PullRequestOpts) Default() PullRequestOpts

type RepoOpts

type RepoOpts struct {
	Host  string
	Owner string
	Name  string
}

Directories

Path Synopsis

Jump to