Documentation
¶
Index ¶
- func ActionAlphaBlendings() carapace.Action
- func ActionAsyncBackends() carapace.Action
- func ActionAutoUpdateModes() carapace.Action
- func ActionBackgroundBlurs() carapace.Action
- func ActionBackgroundImageFits() carapace.Action
- func ActionBackgroundImagePositions() carapace.Action
- func ActionBellFeatures() carapace.Action
- func ActionClipboardPermissions() carapace.Action
- func ActionConfirmCloseSurfaces() carapace.Action
- func ActionCopyOnSelectModes() carapace.Action
- func ActionCursorStyleBlinks() carapace.Action
- func ActionCursorStyles() carapace.Action
- func ActionFontFamilies() carapace.Action
- func ActionFontShapingBreaks() carapace.Action
- func ActionFontSyntheticStyles() carapace.Action
- func ActionFreetypeLoadFlags() carapace.Action
- func ActionFullscreens() carapace.Action
- func ActionGraphemeWidthMethods() carapace.Action
- func ActionGtkQuickTerminalLayers() carapace.Action
- func ActionGtkSingleInstances() carapace.Action
- func ActionGtkTabsLocations() carapace.Action
- func ActionGtkTitlebarStyles() carapace.Action
- func ActionGtkToolbarStyles() carapace.Action
- func ActionInputTypes() carapace.Action
- func ActionLinkPreviewses() carapace.Action
- func ActionLinuxCgroups() carapace.Action
- func ActionMacFullscreenModes() carapace.Action
- func ActionMacIconFrames() carapace.Action
- func ActionMacIcons() carapace.Action
- func ActionMacTitlebarStyles() carapace.Action
- func ActionMacosDockDropBehaviors() carapace.Action
- func ActionMacosHiddenModes() carapace.Action
- func ActionMacosOptionsAsAlt() carapace.Action
- func ActionMacosShortcuts() carapace.Action
- func ActionMacosTitlebarProxyIcons() carapace.Action
- func ActionMacosWindowButtons() carapace.Action
- func ActionMouseShiftCaptureModes() carapace.Action
- func ActionNotifications() carapace.Action
- func ActionNotifyOnCommandFinishActions() carapace.Action
- func ActionNotifyOnCommandFinishes() carapace.Action
- func ActionOscColorReportFormats() carapace.Action
- func ActionQuickTerminalKeyboardInteractivities() carapace.Action
- func ActionQuickTerminalPositions() carapace.Action
- func ActionQuickTerminalScreens() carapace.Action
- func ActionQuickTerminalSpaceBehaviors() carapace.Action
- func ActionReleaseChannels() carapace.Action
- func ActionResizeOverlayModes() carapace.Action
- func ActionResizeOverlayPositions() carapace.Action
- func ActionRightClickActions() carapace.Action
- func ActionScrollToBottoms() carapace.Action
- func ActionScrollbarModes() carapace.Action
- func ActionShaderAnimationModes() carapace.Action
- func ActionShellIntegrationFeatures() carapace.Action
- func ActionShellIntegrationModes() carapace.Action
- func ActionSplitPreserveZooms() carapace.Action
- func ActionTerms() carapace.Action
- func ActionThemes() carapace.Action
- func ActionWindowColorspaces() carapace.Action
- func ActionWindowDecorations() carapace.Action
- func ActionWindowNewTabPositions() carapace.Action
- func ActionWindowPaddingColors() carapace.Action
- func ActionWindowSaveStates() carapace.Action
- func ActionWindowShowTabBars() carapace.Action
- func ActionWindowSubtitles() carapace.Action
- func ActionWindowThemes() carapace.Action
- func Uid(host string, opts ...string) func(s string, uc uid.Context) (*url.URL, error)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ActionAlphaBlendings ¶ added in v1.6.0
ActionAlphaBlendings completes alpha blendings
native (Perform alpha blending in the native color space for the OS) linear (Perform alpha blending in linear space)
func ActionAsyncBackends ¶ added in v1.6.0
ActionAsyncBackends completes async backends
epoll (Use the `epoll` API) io_uring (Use the `io_uring` API)
func ActionAutoUpdateModes ¶
ActionAutoUpdateModes completes auto update modes
off (Disable auto-updates) check (Check for updates)
func ActionBackgroundBlurs ¶ added in v1.7.1
ActionBackgroundBlurs completes background blur modes
false (equivalent to a blur intensity of 0) true (equivalent to the default blur intensity of 20)
func ActionBackgroundImageFits ¶ added in v1.6.0
ActionBackgroundImageFits completes background image fits
contain (scale to the largest size that can still be contained) cover (scale to the smallest size that can completely cover the terminal)
func ActionBackgroundImagePositions ¶ added in v1.6.0
ActionBackgroundImagePositions completes background image positions
top-left top-center
func ActionBellFeatures ¶ added in v1.6.0
ActionBellFeatures completes bell features
audio (Play a custom sound) attention (Request the user's attention when Ghostty is unfocused)
func ActionClipboardPermissions ¶ added in v1.7.1
ActionClipboardPermissions completes clipboard permissions
ask (Ask the user for permission each time a program tries to access the clipboard) allow (Allow clipboard access without prompting)
func ActionConfirmCloseSurfaces ¶ added in v1.7.1
ActionConfirmCloseSurfaces completes confirm-close-surface modes
true (Always confirm before closing) false (Never confirm before closing)
func ActionCopyOnSelectModes ¶
ActionCopyOnSelectModes completes copy-on-select modes
true (prefer to copy to the selection clipboard if supported by the OS) clipboard (always copy text to the selection clipboard)
func ActionCursorStyleBlinks ¶ added in v1.7.1
ActionCursorStyleBlinks completes cursor style blink modes
true (The cursor blinks by default) false (The cursor does not blink)
func ActionFontFamilies ¶ added in v1.6.0
ActionFontFamilies completes font families
FreeMono FreeSans
func ActionFontShapingBreaks ¶ added in v1.7.1
ActionFontShapingBreaks completes font shaping break modes
cursor (Break runs under the cursor)
func ActionFontSyntheticStyles ¶
ActionFontSyntheticStyles completes font synthetic styles
false (completely disable) italic (apply a slant to the glyph)
func ActionFreetypeLoadFlags ¶
ActionFreetypeLoadFlags completes freetype load flags
hinting (Enable hinting) force-autohint (Use the freetype auto-hinter)
func ActionFullscreens ¶ added in v1.7.1
ActionFullscreens completes fullscreen modes
false (Do not start in fullscreen) true (Start in native fullscreen) non-native (Start in non-native fullscreen) non-native-visible-menu (Start in non-native fullscreen, keep menu bar visible) non-native-padded-notch (Start in non-native fullscreen, hide menu bar but pad for notch)
func ActionGraphemeWidthMethods ¶
ActionGraphemeWidthMethods completes grapheme width methods
legacy (Use a legacy method to determine grapheme width) unicode (Use the Unicode standard to determine grapheme width)
func ActionGtkQuickTerminalLayers ¶ added in v1.7.1
ActionGtkQuickTerminalLayers completes gtk quick terminal layers
overlay (appears in front of all windows) top (appears in front of normal windows but behind fullscreen overlays)
func ActionGtkSingleInstances ¶ added in v1.7.1
ActionGtkSingleInstances completes gtk single instance modes
true (Run in single-instance mode) false (Do not run in single-instance mode)
func ActionGtkTabsLocations ¶ added in v1.7.1
ActionGtkTabsLocations completes gtk tabs locations
top (Tab bar at the top of the window) bottom (Tab bar at the bottom of the window)
func ActionGtkTitlebarStyles ¶ added in v1.7.1
ActionGtkTitlebarStyles completes gtk titlebar styles
native (traditional titlebar with a title) tabs (merges the tab bar and the traditional titlebar)
func ActionGtkToolbarStyles ¶ added in v1.6.0
ActionGtkToolbarStyles completes adw toolbar styles
flat (Top and bottom bars are flat with the terminal window) raised (Top and bottom bars cast a shadow on the terminal area)
func ActionInputTypes ¶ added in v1.7.1
ActionInputTypes completes input types
raw (Send raw text as-is) path (Read a filepath and send the contents)
func ActionLinkPreviewses ¶ added in v1.7.1
ActionLinkPreviewses completes link preview modes
true (Show link previews for matched URLs) false (Do not show link previews)
func ActionLinuxCgroups ¶ added in v1.7.1
ActionLinuxCgroups completes linux cgroup modes
never (Never use cgroups) always (Always use cgroups)
func ActionMacFullscreenModes ¶
ActionMacFullscreenModes completes mac fullscreen modes
visible-menu (Use non-native macOS fullscreen, keep the menu bar visible) true (Use non-native macOS fullscreen, hide the menu bar)
func ActionMacIcons ¶
ActionMacIcons completes mac icons
official (Use the official Ghostty icon) custom-style (Use the official Ghostty icon but with custom styles)
func ActionMacTitlebarStyles ¶
ActionMacTitlebarStyles completes mac titlebar styles
native (native macOS titlebar with zero customization) transparent (same as "native" but the titlebar will be transparent)
func ActionMacosDockDropBehaviors ¶ added in v1.7.1
ActionMacosDockDropBehaviors completes macos dock drop behaviors
new-tab (Create a new tab in the current window) new-window (Create a new window unconditionally)
func ActionMacosHiddenModes ¶ added in v1.7.1
ActionMacosHiddenModes completes macos hidden modes
never (The macOS app is never hidden) always (The macOS app is always hidden)
func ActionMacosOptionsAsAlt ¶ added in v1.7.1
ActionMacosOptionsAsAlt completes macos option-as-alt modes
false (Do not treat the Option key as Alt) true (Treat both left and right Option keys as Alt)
func ActionMacosShortcuts ¶ added in v1.7.1
ActionMacosShortcuts completes macos shortcuts modes
ask (Ask the user for permission) allow (Allow Shortcuts to control Ghostty without asking)
func ActionMacosTitlebarProxyIcons ¶ added in v1.7.1
ActionMacosTitlebarProxyIcons completes macos titlebar proxy icon visibility
visible (Show the proxy icon) hidden (Hide the proxy icon)
func ActionMacosWindowButtons ¶ added in v1.7.1
ActionMacosWindowButtons completes macos window buttons visibility
visible (Show the window buttons) hidden (Hide the window buttons)
func ActionMouseShiftCaptureModes ¶
ActionMouseShiftCaptureModes completes mouse shift capture modes
always (always capture) never (never capture)
func ActionNotifications ¶ added in v1.6.0
ActionNotifications completes app notifications
clipboard-copy (Show a notification when text is copied to the clipboard) config-reload (Show a notification when the configuration is reloaded)
func ActionNotifyOnCommandFinishActions ¶ added in v1.7.1
ActionNotifyOnCommandFinishActions completes notify on command finish actions
bell (enabled by default) notify (disabled by default)
func ActionNotifyOnCommandFinishes ¶ added in v1.7.1
ActionNotifyOnCommandFinishes completes notify on command finish modes
never (Never send notifications) unfocused (Only send notifications if the surface is not focused)
func ActionOscColorReportFormats ¶
ActionOscColorReportFormats completes osc color report formats
none (OSC 4/10/11 queries receive no reply) 8-bit (Color components are return unscaled)
func ActionQuickTerminalKeyboardInteractivities ¶ added in v1.7.1
ActionQuickTerminalKeyboardInteractivities completes quick terminal keyboard interactivity modes
none (The quick terminal will not receive any keyboard input) on-demand (The quick terminal would only receive keyboard input when it is focused)
func ActionQuickTerminalPositions ¶
ActionQuickTerminalPositions completes quick terminal positions
top (Terminal appears at the top of the screen) bottom (Terminal appears at the bottom of the screen)
func ActionQuickTerminalScreens ¶
ActionQuickTerminalScreens completes quick terminal screens
main (The screen that the operating system recommends as the main screen) mouse (The screen that the mouse is currently hovered over)
func ActionQuickTerminalSpaceBehaviors ¶ added in v1.7.1
ActionQuickTerminalSpaceBehaviors completes quick terminal space behaviors
move (quick terminal moved to the current space) remain (quick terminal stays in the original space)
func ActionReleaseChannels ¶
ActionReleaseChannels completes release channels
stable (Stable, tagged releases such as \"1.0.0\") tip (Pre-release versions generated from each commit to the main branch)
func ActionResizeOverlayModes ¶
ActionResizeOverlayModes completes resize overlay modes
always (Always show resize overlays) never (Never show resize overlays)
func ActionResizeOverlayPositions ¶
ActionResizeOverlayPositions completes resize overlay positions
center top-left
func ActionRightClickActions ¶ added in v1.7.1
ActionRightClickActions completes right click actions
context-menu (Show the context menu) paste (Paste the contents of the clipboard)
func ActionScrollToBottoms ¶ added in v1.7.1
ActionScrollToBottoms completes scroll-to-bottom modes
keystroke (scroll the surface to the bottom when the user presses a key) output (scroll the surface to the bottom if there is new data to display)
func ActionScrollbarModes ¶ added in v1.7.1
ActionScrollbarModes completes scrollbar modes
system (Respect the system settings) never (Never show a scrollbar)
func ActionShaderAnimationModes ¶
ActionShaderAnimationModes completes shader animation modes
true (run an animation loop when custom shaders are used) false (only render when the terminal is updated)
func ActionShellIntegrationFeatures ¶
ActionShellIntegrationFeatures completes shell integration features
cursor (Set the cursor to a blinking bar at the prompt) sudo (Set sudo wrapper to preserve terminfo)
func ActionShellIntegrationModes ¶
ActionShellIntegrationModes completes shell integration modes
none (Do not do any automatic injection) detect (Detect the shell based on the filename)
func ActionSplitPreserveZooms ¶ added in v1.7.1
ActionSplitPreserveZooms completes split preserve zoom modes
navigation (preserve the zoomed split state when navigating)
func ActionWindowColorspaces ¶ added in v1.7.1
ActionWindowColorspaces completes window colorspaces
srgb display-p3
func ActionWindowDecorations ¶ added in v1.7.1
ActionWindowDecorations completes window decoration modes
none (No window decorations) auto (Automatically choose window decorations)
func ActionWindowNewTabPositions ¶
ActionWindowNewTabPositions completes window tab positions
"current (Insert the new tab after the currently focused tab) "end (Insert the new tab at the end of the tab list)
func ActionWindowPaddingColors ¶
ActionWindowPaddingColors completes window padding colors
background (The background color specified in `background`) extend (Extend the background color of the nearest grid cell)
func ActionWindowSaveStates ¶
ActionWindowSaveStates completes window save states
default (will use the default system behavior) never (will never save window state)
func ActionWindowShowTabBars ¶ added in v1.7.1
ActionWindowShowTabBars completes window show tab bar modes
always (Always display the tab bar) auto (Automatically show and hide the tab bar)
func ActionWindowSubtitles ¶ added in v1.7.1
ActionWindowSubtitles completes window subtitle modes
false (Disable the subtitle) working-directory (Set the subtitle to the working directory)
func ActionWindowThemes ¶
ActionWindowThemes completes window themes
auto (Determine the theme based on the configured terminal background color) system (Use the system theme)
Types ¶
This section is empty.